@@ -1,6 +1,8 @@
 
 using System;
 
+using Mono.Unix;
+
 namespace Tomboy
 {
 	public class Preferences
@@ -10,6 +12,9 @@ namespace Tomboy
 		public const string ENABLE_CUSTOM_FONT = "/apps/tomboy/enable_custom_font";
 		public const string ENABLE_KEYBINDINGS = "/apps/tomboy/enable_keybindings";
 		public const string ENABLE_STARTUP_NOTES = "/apps/tomboy/enable_startup_notes";
+		public const string ENABLE_AUTO_BULLETED_LISTS = "/apps/tomboy/enable_bulleted_lists";
+		public const string ENABLE_ICON_PASTE = "/apps/tomboy/enable_icon_paste";
+		public const string ENABLE_CLOSE_NOTE_ON_ESCAPE = "/apps/tomboy/enable_close_note_on_escape";
 
 		public const string START_NOTE_URI = "/apps/tomboy/start_note";
 		public const string CUSTOM_FONT_FACE = "/apps/tomboy/custom_font_face";
@@ -27,16 +32,18 @@ namespace Tomboy
 		public const string EXPORTHTML_EXPORT_LINKED_ALL = "/apps/tomboy/export_html/export_linked_all";
 
 		public const string STICKYNOTEIMPORTER_FIRST_RUN = "/apps/tomboy/sticky_note_importer/sticky_importer_first_run";
-		
+
 		public const string SYNC_CLIENT_ID = "/apps/tomboy/sync/sync_guid";
 		public const string SYNC_LOCAL_PATH = "/apps/tomboy/sync/sync_local_path";
 		public const string SYNC_SELECTED_SERVICE_ADDIN = "/apps/tomboy/sync/sync_selected_service_addin";
 		public const string SYNC_CONFIGURED_CONFLICT_BEHAVIOR = "/apps/tomboy/sync/sync_conflict_behavior";
 
+		public const string INSERT_TIMESTAMP_FORMAT = "/apps/tomboy/insert_timestamp/format";
+
 		static GConf.Client client;
 		static GConf.NotifyEventHandler changed_handler;
 
-		public static GConf.Client Client 
+		public static GConf.Client Client
 		{
 			get {
 				if (client == null) {
@@ -62,7 +69,16 @@ namespace Tomboy
 
 			case ENABLE_WIKIWORDS:
 				return false;
-			
+
+			case ENABLE_AUTO_BULLETED_LISTS:
+				return true;
+
+			case ENABLE_ICON_PASTE:
+				return false;
+
+			case ENABLE_CLOSE_NOTE_ON_ESCAPE:
+				return true;
+
 			case START_NOTE_URI:
 				return String.Empty;
 
@@ -77,7 +93,7 @@ namespace Tomboy
 
 			case KEYBINDING_SHOW_NOTE_MENU:
 				return "<Alt>F12";
-				
+
 			case KEYBINDING_OPEN_START_HERE:
 				return "<Alt>F11";
 
@@ -88,7 +104,7 @@ namespace Tomboy
 
 			case EXPORTHTML_EXPORT_LINKED:
 				return true;
-			
+
 			case EXPORTHTML_EXPORT_LINKED_ALL:
 				return false;
 
@@ -97,19 +113,22 @@ namespace Tomboy
 
 			case STICKYNOTEIMPORTER_FIRST_RUN:
 				return true;
-			
+
 			case ENABLE_STARTUP_NOTES:
 				return true;
-			
+
 			case SYNC_CLIENT_ID:
 				return System.Guid.NewGuid ().ToString ();
 				break;
-			
+
 			case SYNC_LOCAL_PATH:
 				return string.Empty;
 
 			case SYNC_CONFIGURED_CONFLICT_BEHAVIOR:
 				return 0;
+
+			case INSERT_TIMESTAMP_FORMAT:
+				return Catalog.GetString ("dddd, MMMM d, h:mm tt");
 			}
 
 			return null;
