@@ -50,6 +50,18 @@ namespace Tomboy
 			return true;
 		}
 
+		public bool HideNote (string uri)
+		{
+			Note note;
+
+			note = note_manager.FindByUri (uri);
+			if (note == null)
+				return false;
+
+			note.Window.Hide ();
+			return true;
+		}
+
 		public bool DisplayNoteWithSearch (string uri, string search)
 		{
 			Note note;
@@ -307,7 +319,7 @@ namespace Tomboy
 			Search search =  new Search(note_manager);
 			List<string> list = new List<string>();
 			IDictionary<Note,int> results =
-				search.SearchNotes(query, case_sensitive);
+				search.SearchNotes(query, case_sensitive, null);
 			foreach (Note note in results.Keys) {
 				list.Add (note.Uri);
 			}
